==> bex_flutter_plugin-0.0.1-dev.1.tar.gz: ios/Classes/BexSdk.m <==
#import "BexSdk.h"
#import "BKMExpressPairViewController.h"
#import "BKMExpressPaymentViewController.h"
#import "BexFlutterPlugin.h"


@interface BexSdk () <BKMExpressPairingDelegate,BKMExpressPaymentDelegate>
@end

@implementation BexSdk

static BOOL isDebugMode = NO;

NSString *const ON_PAIRING_SUCCESS = @"onPairingSuccess";
NSString *const ON_PAIRING_FAILURE = @"onPairingFailure";
NSString *const ON_PAIRING_CANCELLED = @"onPairingCancelled";

NSString *const ON_PAYMENT_SUCCESS = @"onPaymentSuccess";
NSString *const ON_PAYMENT_FAILURE = @"onPaymentFailure";
NSString *const ON_PAYMENT_CANCELLED = @"onPaymentCancelled";


+ (void)setDebugMode:(BOOL) newIsdebugMode {
    isDebugMode = newIsdebugMode;
}

+ (void)submitConsumer:(NSString *)token {
    BKMExpressPairViewController *vc = [[BKMExpressPairViewController alloc] initWithToken:token delegate:(id<BKMExpressPairingDelegate>)self];
    [vc setEnableDebugMode:isDebugMode];
    [UIApplication.sharedApplication.delegate.window.rootViewController presentViewController:vc animated:YES completion:nil];
}

+ (void)resubmitConsumer:(NSString *)ticket {
    BKMExpressPairViewController *vc = [[BKMExpressPairViewController alloc] initWithTicket:ticket withDelegate:(id<BKMExpressPairingDelegate>)self];
    [vc setEnableDebugMode:isDebugMode];
    [UIApplication.sharedApplication.delegate.window.rootViewController presentViewController:vc animated:YES completion:nil];
}

+ (void)payment:(NSString *)token {
    BKMExpressPaymentViewController *vc = [[BKMExpressPaymentViewController alloc] initWithPaymentToken:token delegate:(id<BKMExpressPaymentDelegate>)self];
    [vc setEnableDebugMode:isDebugMode];
    [UIApplication.sharedApplication.delegate.window.rootViewController presentViewController:vc animated:YES completion:nil];
}

#pragma Pairing delegate methods

+ (void)bkmExpressPairingDidComplete:(NSString *)first6Digits withLast2Digits:(NSString *)last2Digits{
    NSMutableDictionary *data = [NSMutableDictionary dictionary];
    data[@"first6"] = first6Digits;
    data[@"last2"] = last2Digits;
    [BexFlutterPlugin sendMessage:ON_PAIRING_SUCCESS params:data];
}

+ (void)bkmExpressPairingDidFail:(NSError *)error{
    NSMutableDictionary *data = [NSMutableDictionary dictionary];
    data[@"errorId"] = [NSNumber numberWithInteger:500];
    data[@"errorMsg"] = error.localizedDescription;
    [BexFlutterPlugin sendMessage:ON_PAIRING_FAILURE params:data];
}

+ (void)bkmExpressPairingDidCancel{
    [BexFlutterPlugin sendMessage:ON_PAIRING_CANCELLED params:[NSMutableDictionary dictionary]];
}

#pragma Payment delegate methods

+ (void)bkmExpressPaymentDidCompleteWithPOSResult:(BKMPOSResult *)posResult{
    NSMutableDictionary *data = [NSMutableDictionary dictionary];
    data[@"posMessage"] = [posResult posMessage];
    data[@"md"] = [posResult md];
    data[@"signature"] = [posResult signature];
    data[@"timestamp"] = [posResult timestamp];
    data[@"token"] = [posResult token];
    data[@"xid"] = [posResult xid];
    [BexFlutterPlugin sendMessage:ON_PAYMENT_SUCCESS params:data];
}

+ (void)bkmExpressPaymentDidFail:(NSError *)error{
    NSMutableDictionary *data = [NSMutableDictionary dictionary];
    data[@"errorId"] = [NSNumber numberWithInteger:500];
    data[@"errorMsg"] = error.localizedDescription;
    [BexFlutterPlugin sendMessage:ON_PAYMENT_FAILURE params:data];
}

+ (void)bkmExpressPaymentDidCancel{
    [BexFlutterPlugin sendMessage:ON_PAYMENT_CANCELLED params:[NSMutableDictionary dictionary]];
}

@end

==> bex_flutter_plugin-1.0.0.tar.gz: ios/Classes/BexSdk.m <==
#import "BexSdk.h"
#import "BKMExpressPairViewController.h"
#import "BKMExpressPaymentViewController.h"
#import "BexFlutterPlugin.h"


@interface BexSdk () <BKMExpressPairingDelegate,BKMExpressPaymentDelegate>
@end

@implementation BexSdk

static BOOL isDebugMode = NO;

NSString *const ON_PAIRING_SUCCESS = @"onPairingSuccess";
NSString *const ON_PAIRING_FAILURE = @"onPairingFailure";
NSString *const ON_PAIRING_CANCELLED = @"onPairingCancelled";

NSString *const ON_PAYMENT_SUCCESS = @"onPaymentSuccess";
NSString *const ON_PAYMENT_FAILURE = @"onPaymentFailure";
NSString *const ON_PAYMENT_CANCELLED = @"onPaymentCancelled";


+ (void)setDebugMode:(BOOL) newIsdebugMode {
    isDebugMode = newIsdebugMode;
}

+ (void)submitConsumer:(NSString *)token {
    BKMExpressPairViewController *vc = [[BKMExpressPairViewController alloc] initWithToken:token delegate:(id<BKMExpressPairingDelegate>)self];
    vc.modalPresentationStyle = UIModalPresentationFullScreen;
    [vc setEnableDebugMode:isDebugMode];
    [UIApplication.sharedApplication.delegate.window.rootViewController presentViewController:vc animated:YES completion:nil];
}

+ (void)resubmitConsumer:(NSString *)ticket {
    BKMExpressPairViewController *vc = [[BKMExpressPairViewController alloc] initWithTicket:ticket withDelegate:(id<BKMExpressPairingDelegate>)self];
    vc.modalPresentationStyle = UIModalPresentationFullScreen;
    [vc setEnableDebugMode:isDebugMode];
    [UIApplication.sharedApplication.delegate.window.rootViewController presentViewController:vc animated:YES completion:nil];
}

+ (void)payment:(NSString *)token {
    BKMExpressPaymentViewController *vc = [[BKMExpressPaymentViewController alloc] initWithPaymentToken:token delegate:(id<BKMExpressPaymentDelegate>)self];
    vc.modalPresentationStyle = UIModalPresentationFullScreen;
    [vc setEnableDebugMode:isDebugMode];
    [UIApplication.sharedApplication.delegate.window.rootViewController presentViewController:vc animated:YES completion:nil];
}

#pragma Pairing delegate methods

+ (void)bkmExpressPairingDidComplete:(NSString *)first6Digits withLast2Digits:(NSString *)last2Digits{
    NSMutableDictionary *data = [NSMutableDictionary dictionary];
    data[@"first6"] = first6Digits;
    data[@"last2"] = last2Digits;
    [BexFlutterPlugin sendMessage:ON_PAIRING_SUCCESS params:data];
}

+ (void)bkmExpressPairingDidFail:(NSError *)error{
    NSMutableDictionary *data = [NSMutableDictionary dictionary];
    data[@"errorId"] = [NSNumber numberWithLong:error.code];
    data[@"errorMsg"] = error.localizedDescription;
    [BexFlutterPlugin sendMessage:ON_PAIRING_FAILURE params:data];
}

+ (void)bkmExpressPairingDidCancel{
    [BexFlutterPlugin sendMessage:ON_PAIRING_CANCELLED params:[NSMutableDictionary dictionary]];
}

#pragma Payment delegate methods

+ (void)bkmExpressPaymentDidCompleteWithPOSResult:(BKMPOSResult *)posResult{
    NSMutableDictionary *data = [NSMutableDictionary dictionary];
    data[@"posMessage"] = [posResult posMessage];
    data[@"md"] = [posResult md];
    data[@"signature"] = [posResult signature];
    data[@"timestamp"] = [posResult timestamp];
    data[@"token"] = [posResult token];
    data[@"xid"] = [posResult xid];
    [BexFlutterPlugin sendMessage:ON_PAYMENT_SUCCESS params:data];
}

+ (void)bkmExpressPaymentDidFail:(NSError *)error{
    NSMutableDictionary *data = [NSMutableDictionary dictionary];
    data[@"errorId"] = [NSNumber numberWithLong:error.code];
    data[@"errorMsg"] = error.localizedDescription;
    [BexFlutterPlugin sendMessage:ON_PAYMENT_FAILURE params:data];
}

+ (void)bkmExpressPaymentDidCancel{
    [BexFlutterPlugin sendMessage:ON_PAYMENT_CANCELLED params:[NSMutableDictionary dictionary]];
}

@end
